@@ -22,18 +22,26 @@ STABLE.
 """
 
 import logging
+
 import six
+import gi
+gi.require_version('TelepathyGLib', '0.12')
 from gi.repository import GObject
 import dbus
-from telepathy.interfaces import CONNECTION, \
-    CONNECTION_INTERFACE_ALIASING, \
-    CONNECTION_INTERFACE_CONTACTS
-from telepathy.constants import HANDLE_TYPE_CONTACT
 
 from sugar3.presence.connectionmanager import get_connection_manager
 from sugar3.profile import get_color, get_nick_name
 
-ACCOUNT_MANAGER_SERVICE = 'org.freedesktop.Telepathy.AccountManager'
+from gi.repository import TelepathyGLib
+
+CONNECTION = TelepathyGLib.IFACE_CONNECTION
+CONNECTION_INTERFACE_ALIASING = \
+    TelepathyGLib.IFACE_CONNECTION_INTERFACE_ALIASING
+CONNECTION_INTERFACE_CONTACTS = \
+    TelepathyGLib.IFACE_CONNECTION_INTERFACE_CONTACTS
+
+HANDLE_TYPE_CONTACT = TelepathyGLib.HandleType.CONTACT
+
 CONN_INTERFACE_BUDDY_INFO = 'org.laptop.Telepathy.BuddyInfo'
 
 _logger = logging.getLogger('sugar3.presence.buddy')
@@ -164,20 +172,29 @@ class Buddy(BaseBuddy):
                                      dbus_interface=CONNECTION)
         self.contact_handle = handles[0]
 
-        arg_dict = dict(reply_handler=self.__got_properties_cb,
-                        error_handler=self.__error_handler_cb,
-                        byte_arrays = True)
         if six.PY2:
-            arg_dict = arg_dict.update(utf8_strings=True)
-
-        self._get_properties_call = bus.call_async(
-            connection_name,
-            connection.object_path,
-            CONN_INTERFACE_BUDDY_INFO,
-            'GetProperties',
-            'u',
-            (self.contact_handle,),
-            arg_dict)
+            self._get_properties_call = bus.call_async(
+                connection_name,
+                connection.object_path,
+                CONN_INTERFACE_BUDDY_INFO,
+                'GetProperties',
+                'u',
+                (self.contact_handle,),
+                reply_handler=self.__got_properties_cb,
+                error_handler=self.__error_handler_cb,
+                utf8_strings=True,
+                byte_arrays=True)
+        else:
+            self._get_properties_call = bus.call_async(
+                connection_name,
+                connection.object_path,
+                CONN_INTERFACE_BUDDY_INFO,
+                'GetProperties',
+                'u',
+                (self.contact_handle,),
+                reply_handler=self.__got_properties_cb,
+                error_handler=self.__error_handler_cb,
+                byte_arrays=True)
 
         self._get_attributes_call = bus.call_async(
             connection_name,
